==> zio-aws-appmesh_2.13-5.17.123.2-sources.jar: zio/aws/appmesh/model/CreateVirtualServiceRequest.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.appmesh.model.primitives.{ServiceName, AccountId, ResourceName}
import scala.jdk.CollectionConverters._
final case class CreateVirtualServiceRequest(
    clientToken: Option[String] = None,
    meshName: ResourceName,
    meshOwner: Option[AccountId] = None,
    spec: zio.aws.appmesh.model.VirtualServiceSpec,
    tags: Option[Iterable[zio.aws.appmesh.model.TagRef]] = None,
    virtualServiceName: ServiceName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.CreateVirtualServiceRequest = {
    import CreateVirtualServiceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.CreateVirtualServiceRequest
      .builder()
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .spec(spec.buildAwsValue())
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .virtualServiceName(
        ServiceName.unwrap(virtualServiceName): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.CreateVirtualServiceRequest.ReadOnly =
    zio.aws.appmesh.model.CreateVirtualServiceRequest.wrap(buildAwsValue())
}
object CreateVirtualServiceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.CreateVirtualServiceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.CreateVirtualServiceRequest =
      zio.aws.appmesh.model.CreateVirtualServiceRequest(
        clientToken.map(value => value),
        meshName,
        meshOwner.map(value => value),
        spec.asEditable,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        virtualServiceName
      )
    def clientToken: Option[String]
    def meshName: ResourceName
    def meshOwner: Option[AccountId]
    def spec: zio.aws.appmesh.model.VirtualServiceSpec.ReadOnly
    def tags: Option[List[zio.aws.appmesh.model.TagRef.ReadOnly]]
    def virtualServiceName: ServiceName
    def getClientToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getSpec
        : ZIO[Any, Nothing, zio.aws.appmesh.model.VirtualServiceSpec.ReadOnly] =
      ZIO.succeed(spec)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.appmesh.model.TagRef.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getVirtualServiceName: ZIO[Any, Nothing, ServiceName] =
      ZIO.succeed(virtualServiceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.CreateVirtualServiceRequest
  ) extends zio.aws.appmesh.model.CreateVirtualServiceRequest.ReadOnly {
    override val clientToken: Option[String] =
      scala.Option(impl.clientToken()).map(value => value: String)
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Option[AccountId] = scala
      .Option(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val spec: zio.aws.appmesh.model.VirtualServiceSpec.ReadOnly =
      zio.aws.appmesh.model.VirtualServiceSpec.wrap(impl.spec())
    override val tags: Option[List[zio.aws.appmesh.model.TagRef.ReadOnly]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.appmesh.model.TagRef.wrap(item)
          }.toList
        )
    override val virtualServiceName: ServiceName =
      zio.aws.appmesh.model.primitives.ServiceName(impl.virtualServiceName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.CreateVirtualServiceRequest
  ): zio.aws.appmesh.model.CreateVirtualServiceRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-appmesh_2.13-5.17.193.1-sources.jar: zio/aws/appmesh/model/CreateVirtualServiceRequest.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appmesh.model.primitives.{ServiceName, AccountId, ResourceName}
import scala.jdk.CollectionConverters._
final case class CreateVirtualServiceRequest(
    clientToken: Optional[String] = Optional.Absent,
    meshName: ResourceName,
    meshOwner: Optional[AccountId] = Optional.Absent,
    spec: zio.aws.appmesh.model.VirtualServiceSpec,
    tags: Optional[Iterable[zio.aws.appmesh.model.TagRef]] = Optional.Absent,
    virtualServiceName: ServiceName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.CreateVirtualServiceRequest = {
    import CreateVirtualServiceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.CreateVirtualServiceRequest
      .builder()
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .spec(spec.buildAwsValue())
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .virtualServiceName(
        ServiceName.unwrap(virtualServiceName): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.CreateVirtualServiceRequest.ReadOnly =
    zio.aws.appmesh.model.CreateVirtualServiceRequest.wrap(buildAwsValue())
}
object CreateVirtualServiceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.CreateVirtualServiceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.CreateVirtualServiceRequest =
      zio.aws.appmesh.model.CreateVirtualServiceRequest(
        clientToken.map(value => value),
        meshName,
        meshOwner.map(value => value),
        spec.asEditable,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        virtualServiceName
      )
    def clientToken: Optional[String]
    def meshName: ResourceName
    def meshOwner: Optional[AccountId]
    def spec: zio.aws.appmesh.model.VirtualServiceSpec.ReadOnly
    def tags: Optional[List[zio.aws.appmesh.model.TagRef.ReadOnly]]
    def virtualServiceName: ServiceName
    def getClientToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getSpec
        : ZIO[Any, Nothing, zio.aws.appmesh.model.VirtualServiceSpec.ReadOnly] =
      ZIO.succeed(spec)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.appmesh.model.TagRef.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getVirtualServiceName: ZIO[Any, Nothing, ServiceName] =
      ZIO.succeed(virtualServiceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.CreateVirtualServiceRequest
  ) extends zio.aws.appmesh.model.CreateVirtualServiceRequest.ReadOnly {
    override val clientToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.clientToken())
      .map(value => value: String)
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val spec: zio.aws.appmesh.model.VirtualServiceSpec.ReadOnly =
      zio.aws.appmesh.model.VirtualServiceSpec.wrap(impl.spec())
    override val tags: Optional[List[zio.aws.appmesh.model.TagRef.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.appmesh.model.TagRef.wrap(item)
          }.toList
        )
    override val virtualServiceName: ServiceName =
      zio.aws.appmesh.model.primitives.ServiceName(impl.virtualServiceName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.CreateVirtualServiceRequest
  ): zio.aws.appmesh.model.CreateVirtualServiceRequest.ReadOnly = new Wrapper(
    impl
  )
}
